__title__ = 'Django RESTQL'
__description__ = 'Turn your API made with Django REST Framework(DRF) into a GraphQL like API.'
__url__ = 'https://yezyilomo.github.io/django-restql'
__version__ = '0.12.0'
__author__ = 'Yezy Ilomo'
__author_email__ = 'yezileliilomo@hotmail.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2019 Yezy Ilomo'

# Version synonym
VERSION = __version__
